==> library1.4.1.tar.bz2: library/izd/editform.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['menu-btn22'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$button = $TEXT['btn_save'];
$action = "edit.php";

if(strlen($_GET['izd_id'])>5) {puterror($result2['skin'],$TEXT['error-izd6']); require_once "../utils/bottom_adm.php"; exit();}
 $_GET['izd_id'] = rep($_GET['izd_id']);

$old_izd_id = $_GET['izd_id'];

$query10 = "SELECT * FROM `tbl_izdatelstvo` WHERE `izd_id`='".$_GET['izd_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl6']); require_once "../utils/bottom_adm.php"; exit();}
   $result_izd = mysqli_fetch_array($result10);
    $izd = $result_izd['izdatelstvo'];
    $tip_pr = $result_izd['site_protocol'];
    $addr = $result_izd['site_name'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="inform"><?php echo $TEXT['tbl-izd']; ?>:</td><td><input size=50 maxlength=127 class="input" type=text name=izd value='<?php echo $izd; ?>'></td></tr>
<tr><td class="inform"><?php echo $TEXT['user-adrr']; ?>:</td><td>
    <select name=tip_pr>
    <option value='http' <?php if($tip_pr =='http') {echo "selected";} ?>>http
    <option value='https' <?php if($tip_pr =='https') {echo "selected";} ?>>https
    <option value='ftp' <?php if($tip_pr =='ftp') {echo "selected";} ?>>ftp
</select>
    ://
    <input size=30 maxlength=127 type=text name=addr value='<?php echo $addr; ?>'></td></tr>
<tr><td></td><td>
<input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=izd_id value='<?php echo $old_izd_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/izd/editform.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['menu-btn22'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$button = $TEXT['btn_save'];
$action = "edit.php";

if(strlen($_GET['izd_id'])>5) {puterror($result2['skin'],$TEXT['error-izd6']); require_once "../utils/bottom_adm.php"; exit();}
 $_GET['izd_id'] = rep($_GET['izd_id']);

$old_izd_id = $_GET['izd_id'];

$query10 = "SELECT * FROM `tbl_izdatelstvo` WHERE `izd_id`='".$_GET['izd_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl6']); require_once "../utils/bottom_adm.php"; exit();}
   $result_izd = mysqli_fetch_array($result10);
    $izd = rep_back($result_izd['izdatelstvo']);
    $tip_pr = $result_izd['site_protocol'];
    $addr = $result_izd['site_name'];
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="inform"><?php echo $TEXT['tbl-izd']; ?>:</td><td><input size="50" maxlength="127" type="text" name="izd" value="<?php echo $izd; ?>" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['user-adrr']; ?>:</td><td>
    <select name="tip_pr">
    <option value="http" <?php if($tip_pr =='http') {echo "selected";} ?>>http
    <option value="https" <?php if($tip_pr =='https') {echo "selected";} ?>>https
    <option value="ftp" <?php if($tip_pr =='ftp') {echo "selected";} ?>>ftp
</select>
    ://
    <input size="30" maxlength="127" type="text" name="addr" value="<?php echo $addr; ?>" /></td></tr>
<tr><td></td><td>
<input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="izd_id" value="<?php echo $old_izd_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
